@@ -18,7 +18,7 @@
 package main
 
 import (
-	"fixme/pkg_recommend"
+	"internal/utils/fixme/pkg_recommend"
 )
 
 func QueryEnhancedLocalePackages(checker func(string) bool, lang string, pkgs ...string) []string {
